lyricstools.LyricText
=====================

.. inheritance-diagram:: abjad.tools.lyricstools.LyricText.LyricText.LyricText
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.LyricText.LyricText.LyricText

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.duration_in_seconds

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.format

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.leaf_index

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.multiplied_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.preprolated_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.duration_multiplier

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_duration

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_pitch_indication_is_at_sounding_pitch

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. autoattribute:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.written_pitch_indication_is_nonsemantic

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__and__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__or__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__repr__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__str__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__sub__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`

.. automethod:: abjad.tools.lyricstools.LyricText.LyricText.LyricText.__xor__

    Inherited from :py:class:`leaftools.Leaf <abjad.tools.leaftools.Leaf.Leaf.Leaf>`
